| cnefe_dictionary | R Documentation |
Opens the bundled Excel data dictionary in the system's default spreadsheet viewer (e.g., Excel, LibreOffice).
cnefe_dictionary(year = 2022)
year |
Integer. The CNEFE data year. Currently only 2022 is supported. |
Invisibly, the path to the Excel file inside the installed package.
cnefe_dictionary()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.