tracts_variables_ref: Reference table for tracts_to_* function variables

tracts_variables_refR Documentation

Reference table for tracts_to_* function variables

Description

A data frame that maps variable names used in tracts_to_h3() and tracts_to_polygon() to the census tract variable codes and descriptions.

Usage

tracts_variables_ref

Format

A data frame with 22 rows and 4 columns:

var_cnefetools

Variable name used in cnefetools functions.

code_var_ibge

Variable code in the census tract aggregates, as used by censobr.

desc_var_ibge

Official IBGE variable description in Portuguese.

table_ibge

Census tract table where the variable is found (Domicilios, Pessoas, or ResponsavelRenda), which correspond to the censobr datasets Domicilio, Pessoas and ResponsavelRenda.

Details

The variable codes are the ones used by the censobr package, which repackages the IBGE census tract aggregates and is where the census tract assets take their attributes from (see data-raw/sc_assets_build.R in the package repository), and each table corresponds to a censobr dataset. They don't always match the file and column names on the IBGE FTP server.

IBGE - Censo Demografico 2022, Agregados por Setores Censitarios, as repackaged by the censobr package.

Examples

# View the reference table
tracts_variables_ref

# Find the IBGE code for a specific variable
tracts_variables_ref[tracts_variables_ref$var_cnefetools == "pop_ph", ]


cnefetools documentation built on Oct. 2, 2026, 1:08 a.m.